==> win32_Release_v3.2.6_r375.zip: data/scripts/ui/shop/PopupShopOffers.lua <==
amta`D  VRmhK#L<ssd7
*Q,&,UU[uQ"tytTiI/N"Q4ԼӤӼȍ▶Ŭa`m/J,C1Txx~
cb>>JHNxe5T:_3Ҿջozz{S C1T1_ezSZPYtYynn:_ښ؍ĐkjBӰīȩ::y+71"E T8::;:0:3Z<ho
*^6S=7>+)+ns~Ѵձ~hOͽ
	8437=4=˪Ϊ8(BQ7X́͡>}_=T3k\|A>>%$7+MLnBeMI1kpyQv?{(w5y8{0o"c1z?kLeIi(:!>>" _]v60uu/-~ڳ޻؇©Αϭю=;?
4*
9 nlFkk]y{	9O\uXps4>;r*A"M#SJ@(]9flm2F/B'9mhllAlGŠΪ
i󓘲! X\icR/{HaAO;^&?WY+Wu-g2=jwS6B6S!	Z*O,E$H$XӛC&K*C-[]u\{NEvGsxRnCAKBKBKߟ `؍ĸʹĥUW%+m3m[^]4PxQ/GUѼ((O*^t
H'i:N<ä;/&ꊋԼݳԱѣ{|rya߳	!N c`v^VQzt<r)AQqF?4$.V]^gR~^lYtؠ̅ȍҞ۝%%UݱP8fm@t6>^[+=QX<28q`!M=U4,7枙uu	411Iت=
cg5ݟɱB@hJ45]H

 _=I'xJ{fj$(ʷgyK?D&%|FyuO-عͨ,koڊ؝Ν؜	_M>[yu{KgWo|u~=R>Q#
Z2[/J_"
&) 'svƤоҷѣƵݞ7=3??5?6旸Kb4\aPףѾ;>툠#73Al=<Y7Cy]^txQw_oZef3C'
1x%%<fIUV~_o2	.`qV궰laN488:U;ґPW9X5miǫǥħ̗;:
6d<TVgW"Q%J'wj_)
ƏǢYX[+J8Y4,UTyY)!"<8Uo3nlki`qStTijXϪ٭°ꆀ>19UhD0:21US򩂻6:<620$%XMjsUe蚲*3=Gk893=54>׸ܴeKWQ{m]y׳XcdHpbMcg'(tw[`3,+iIewhNw]q\Һ⪟#)lF-
ƥ׸%	Ztt]$ԭݸޑÙ	9	%/[Z2qs I3V~W27	((M?֗@E$Hk
i$婙㯄@Ahʣײ߬#]x,]4\]^sSbB&IkgacM5(꒲ɾ׳ǯƯkcA	"!ե_^r7;ܹͬ#B`,}k]䮯cdFJp^'.[IjW7(ؤ]nSa2NLq`lo022bg/aP.eTdN-'37<Dem4@9D6O<H)E)`]U_pcJ`@AB}{v=<do^ǆ{y^ΣUPhLMH ex;Z(LlnBCd涴Cr<.ҽӝߪoX4Gԑ΃ 1e` qSْ×ܼPP !@VL]xrZ" _Tx T|,-
.%P)Wyqm
!=MBAzu)x^vf[30fFeQ5퉌]X<7@Dmi/
-uqB>?	).%9-$E+Oo^~cD D?>i`Ž`9X4<xrrp ai6Z?X=S7V$]wpwURZyоjD|[ڪN`\G$y.)090Dt+*
7547(hKg3KNf'$ܹ5ysz~u:݈֙āҦbCr׫掛>sbcDb_Z[/J':򞛳$t{P+26rqРZQe@>04(3! p~Z~ڻע-\PFCۛu^nqp2W$P2rsT8#ppW$PrKar[,Yӌνɨk89<?
!,#WZ`CC߭,*Y|<FRXhFq|0:wA09۽rPd% eQgKii%|6ݠO)(PdOW64TB4[1^0Dg~J>ޠR[XhDdIxMoؤ+GJZzq$}xPj<1o{[
cpWHAtB.+J<[,8aֺ捭^We^(!-sV}x= ,z? I~MAySƴ0&

c╱>;)"y O:W5	ɷuUfO{kYHxM|H}T.-A.	*wr$+ פТ\)`Hn8ļpjDDl icKLiݹ(y[Wěʨ(˷ϸ.*aB6/ͦx7Y7P<Yq\mU?	ȴ#Ѡ+'-
  +ϧ9`Bf͡9Y
*e%!ʭȼ|*JCjH		/W( c1h;o.b1n'nL̳_Cct47ngd3oω	.e#ViZ20rmSFrpEqYۦ:
/s}vTr# 	+8.aIk" "V9niKwMleG==I]5ॎ	Y\YJWPG#1;L혻. 'Ք+ gIkD.7>7+,5
14Ԭ_Q1@$E=>Uo[ꪮfaA`X\<@0Qs/;;wٖЖӁҍޖىRv'EyPHj8}ptXxx_y-:6B"t] ]4GZhSfuFdmO,
?roAnooK.3)
ŵMUl1eG'<|U/Hbvq{3v$k.}"a r6eB|lK406qGe^AmٚlC?7O2KƢ'﯋$ "*(+E" EDM~Hbbz
?+N}G`QCǌ,9<L9K(@!R7A/.N
~zR܄/da3V%J?M.Ki<齛ѿjfe5G.M( *Q%X~:ìNyİKIn!NdhV\Uq]%0Dbr*uR3HfDW)ʂ6J#rEboC`gةEG#=M,>rzy{W"[..,,X^fw5@)E!@JbF֍Z7Xh͡*>/շ)̥ղǨ̩w*!rgW6E kH'In1R:Y}a`ӽ0Ⱥ3S
/5ŊͨƲץ;vvR#GDjz{yx%il}S^\1--Z}5fd6Y6B0$+8'7#"3X|BNDMD
exwuhiJrێ0#'bb
]yنSP~(0abECQKB7Y+9\]n盠gdC70F.Y_f-+cavp>G4իЭP!qR:4H}Z@PxQflHG.76Q.$DBk+ب%'|7b	!Ha
_R:1k^&򀞰dLȜѸ˿5ef')}aF~~\(V  \[u%mm\ߝx@C`4?ۿ-y28;;;WH̸ٷltV$WwYmn=xuWoX7ÀNf}Um+$[Alr2&FT@y->=R<Y.7%K.Y~?4Z?H0{V;zv{[=T:%62۩198Vp\`aCЋ⿟lCKGv+
<*lNf,5E9(
-YzS@FmM| hjO²_Llb& F᭫糵^^~v*,Ȭaj2럙➘:I^aqs6uuS:o%$@)O)-8`yY]QSw.raV\U\7gutXR[RuloH
)20嘽wQy	l*{jst[.GhJ /۬R 6&-'	+gGm	+54Hԧf:oOj&`+0֖rP,ήAcb񒠈¬

==> win32_Release_v4.0.1_r899.zip: data/scripts/ui/shop/PopupShopOffers.lua <==
amtaSD  VRmhK#L<ssd7
*Q,&,UU[uQ"tytTiI/N"Q4ԼӤӼȍ▶Ŭa`m/J,C1Txx~
cb>>JHNxe5T:_3Ҿջozz{S C1T1_ezSZPYtYynn:_ښ؍ĐkjBӰīȩ::y+71"E T8::;:0:3Z<ho
*^6S=7>+)+ns~Ѵձ~hOͽ
	8437=4=˪Ϊ8(BQ7X́͡>}_=T3k\|A>>%$7+MLnBeMI1kpyQv?{(w5y8{0o"c1z?kLeIi(:!>>" _]v60uu/-~ڳ޻؇©Αϭю=;?
4*
9 nlFkk]y{	9O\uXps4>;r*A"M#SJ@(]9flm2F/B'9mhllAlGŠΪ
i󓘲! X\icR/{HaAO;^&?WY+Wu-g2=jwS6B6S!	Z*O,E$H$XӛC&K*C-[]u\{NEvGsxRnCAKBKBKߟ `؍ĸʹĥUW%+m3m[^]4PxQ/GUѼ((O*^t
H'i:N<ä;/&ꊋԼݳԱѣ{|rya߳	!N c`v^VQzt<r)AQqF?4$.V]^gR~^lYtؠ̅ȍҞ۝%%UݱP8fm@t6>^[+=QX<28q`!M=U4,7枙uu	411Iت=
cg5ݟɱB@hJ45]H

 _=I'xJ{fj$(ʷgyK?D&%|FyuO-عͨ,koڊ؝Ν؜	_M>[yu{KgWo|u~=R>Q#
Z2[/J_"
&) 'svƤоҷѣƵݞ7=3??5?6旸Kb4\aPףѾ;>툠#73Al=<Y7Cy]^txQw_oZef3C'
1x%%<fIUV~_o2	.`qV궰laN488:U;ґPW9X5miǫǥħ̗;:
6d<TVgW"Q%J'wj_)
ƏǢYX[+J8Y4,UTyY)!"<8Uo3nlki`qStTijXϪ٭°ꆀ>19UhD0:21US򩂻6:<620$%XMjsUe蚲*3=Gk893=54>׸ܴeKWQ{m]y׳XcdHpbMcg'(tw[`3,+iIewhNw]q\Һ⪟#)lF-
ƥ׸%	Ztt]$ԭݸޑÙ	9	%/[Z2qs I3V~W27	((M?֗@E$Hk
i$婙㯄@Ahʣײ߬#]x,]4\]^sSbB&IkgacM5(꒲ɾ׳ǯƯkcA	"!ե_^r7;ܹͬ#B`,}k]䮯cdFJp^'.[IjW7(ؤ]nSa2NLq`lo022bg/aP.eTdN-'37<Dem4@9D6O<H)E)`]U_pcJ`@AB}{v=<do^ǆ{y^ΣUPhLMH ex;Z(LlnBCd涴Cr<.ҽӝߪoX4Gԑ΃ 1e` qSْ×ܼPP !@VL]xrZ" _Tx T|,-
.%P)Wyqm
!=MBAzu)x^vf[30fFeQ5퉌]X<7@Dmi/
-uqB>?	).%9-$E+Oo^~cD D?>i`Ž`9X4<xrrp ai6Z?X=S7V$]wpwURZyоjD|[ڪN`\G$y.)090Dt+*
7547(hKg3KNf'$ܹ5ysz~u:݈֙āҦbCr׫掛>sbcDb_Z[/J':򞛳$t{P+26rqРZQe@>04(3! p~Z~ڻע-\PFCۛu^nqp2W$P2rsT8#ppW$PrKar[,Yӌνɨk89<?
!,#WZ`CC߭,*Y|<FRXhFq|0:wA09۽rPd% eQgKii%|6ݠO)(PdOW64TB4[1^0Dg~J>ޠR[XhDdIxMoؤ+GJZzq$}xPj<1o{[
cpWHAtB.+J<[,8aֺ捭^We^(!-sV}x= ,z? I~MAySƴ0&

c╱>;)"y O:W5	ɷuUfO{kYHxM|H}T.-A.	*wr$+ פТ\)`Hn8ļpjDDl icKLiݹ(y[Wěʨ(˷ϸ.*aB6/ͦx7Y7P<Yq\mU?	ȴ#Ѡ+'-
  +ϧ9`Bf͡9Y
*e%!ʭȼ|*JCjH		/W( c1h;o.b1n'nL̳_Cct47ngd3oω	.e#ViZ20rmSFrpEqYۦ:
/s}vTr# 	+8.aIk" "V9niKwMleG==I]5ॎ	Y\YJWPG#1;L혻. 'Ք+ gIkD.7>7+,5
14Ԭ_Q1@$E=>Uo[ꪮfaA`X\<@0Qs/;;wٖЖӁҍޖىRv'EyPHj8}ptXxx_y-:6B"t] ]4GZhSfuFdmO,
?roAnooK.3)
ŵMUl1eG'<|U/Hbvq{3v$k.}"a r6eB|lK406qGe^AmٚlC?7O2KƢ'﯋$ "*(+E" EDM~Hbbz
?+N}G`QCǌ,9<L9K(@!R7A/.N
~zR܄/da3V%J?M.Ki<齛ѿjfe5G.M( *Q%X~:ìNyİKIn!NdhV\Uq]%0Dbr*uR3HfDW)ʂ6J#rEboC`gةEG#=M,>rzy{W"[..,,X^fw5@)E!@JbF֍Z7Xh͡*>/շ*ˢEF^p^-?ry^:go3G"J)
+	@.w@,pRtx776ReK[ZXYͬũ-QT֮S}pr8?#Urf57e
eAc`' ; 2iaƈ۲Խ޿ˢͣ93/-x}|eE&تطï!,C-oj@56jN :26&&>ӆ;&#*#7GFl40LwX孍!/,֥мo32	trUqY="#a s1+;:
#nK>Sf1
>ٰ6 .~ф͉Ȍ|bL-cKϛ̸ֿ2T}Z5

{/[x)̿*j`gI=>QQ`PijIi@bҶ$XqV])H:Rh@
 -Y^X=N`up\|ԧ)
vsT舅+@gw4!#Khv u͋85|qV!ҒZtZfѾеn<ɧµBOdضӤܗCFdg>&#L/N"d
c@, 'ϽϏ݆ﲒ=M'z\!7qSɉó1<7+`BNK?9*^}TGAjJ{omH3-?*;=?RTy=<LJm??7SUr*
99+`fNo2agKc	}jBk`J(lIu?>Z3U37Wr}Z	d::ojVP<?	AMmPpZjihDNG:
,xبͣڹˢҦ^C&QsUQf%	)xװաmCay7:&?! \=􇳔hUuVO(
](
<7Eg/ޢ;IllmlpPc 2*&?5P>ZKKK
